Class: SpreeCmCommissioner::Events::FindMatches

Inherits:
Spree::BaseFinder
  • Object
show all
Defined in:
app/finders/spree_cm_commissioner/events/find_matches.rb

Instance Method Summary collapse

Instance Method Details

#executeObject

currently, there is no way to determine if an event is a match yet. this finder returns all events that have active integration mappings (synced from external systems like StadiumX) as a temporary workaround to filter out non-match events.



7
8
9
10
11
12
# File 'app/finders/spree_cm_commissioner/events/find_matches.rb', line 7

def execute
  scope.joins(:integration_mappings).where(
    kind: :event,
    integration_mappings: { status: :active }
  ).distinct
end