Module: SpreeCmCommissioner::PurchaseLimitable
- Extended by:
- ActiveSupport::Concern
- Defined in:
- app/models/concerns/spree_cm_commissioner/purchase_limitable.rb
Constant Summary collapse
- PURCHASE_LIMIT_KEYS =
%i[ max_quantity_per_order max_quantity_per_account max_quantity_per_device max_quantity_per_ip ].freeze
- AGGREGATE_LIMIT_KEYS =
Caps that aggregate across orders. The order cap is bounded by each of these: whichever is smaller is what the buyer actually gets.
%i[ max_quantity_per_account max_quantity_per_device max_quantity_per_ip ].freeze
- POSITIVE_INTEGER =
{ only_integer: true, greater_than: 0, message: :must_be_positive_integer }.freeze