Class: SpreeCmCommissioner::Guest
Overview
rubocop:disable Metrics/ClassLength
Constant Summary
SpreeCmCommissioner::GuestDataFillStageConcern::STAGES
Constants included
from KycBitwise
KycBitwise::BIT_FIELDS, KycBitwise::KYC_FIELD_ATTRIBUTES, KycBitwise::ORDERED_BIT_FIELDS
Class Method Summary
collapse
Instance Method Summary
collapse
#any_fields_exist_for?, #incomplete?, #refresh_data_fill_stage, #stage_completed?
Methods included from KycBitwise
#available_social_contact_platforms, #kyc?, #kyc_fields, #kyc_value_enabled?, #unordered_kyc_fields
Class Method Details
.csv_importable_columns ⇒ Object
84
85
86
87
88
89
90
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 84
def self.csv_importable_columns
%i[
first_name last_name phone_number age dob gender address other_occupation
entry_type nationality_id other_organization expectation emergency_contact bib_number
preferred_telegram_user_id seat_number country_code contact
]
end
|
.variants_for_rules(rules) ⇒ Object
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 339
def self.variants_for_rules(rules)
variant_ids = rules.flat_map do |rule|
case rule.ruleable_type
when 'Spree::Product', 'Spree::OptionValue'
rule.ruleable&.variants&.pluck(:id)
when 'Spree::Variant'
[rule.ruleable_id]
else
[]
end
end.compact.flatten.uniq
return [] if variant_ids.empty?
Spree::Variant.where(id: variant_ids).includes(:product, :option_values)
end
|
Instance Method Details
#allowed_checkout? ⇒ Boolean
no validation for each field as we allow user to save data to model partially.
107
108
109
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 107
def allowed_checkout?
kyc_fields.all? { |field| allowed_checkout_for?(field) }
end
|
#allowed_checkout_for?(field) ⇒ Boolean
rubocop:disable Metrics/AbcSize, Metrics/PerceivedComplexity, Metrics/CyclomaticComplexity
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 111
def allowed_checkout_for?(field) return first_name.present? && last_name.present? if field == :guest_name
return gender.present? if field == :guest_gender
return dob.present? if field == :guest_dob
return occupation.present? || other_occupation.present? if field == :guest_occupation
return nationality.present? if field == :guest_nationality
return age.present? if field == :guest_age
return emergency_contact.present? if field == :guest_emergency_contact
return other_organization.present? if field == :guest_organization
return expectation.present? if field == :guest_expectation
return social_contact_platform.present? && social_contact.present? if field == :guest_social_contact
return upload_later? || (id_card.present? && id_card.allowed_checkout?) if field == :guest_id_card
return address.present? if field == :guest_address
return phone_number.present? if field == :guest_phone_number
return country_code.present? if field == :guest_country_code
return contact.present? if field == :guest_contact
false
end
|
#allows_gift_transfer? ⇒ Boolean
381
382
383
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 381
def allows_gift_transfer?
line_item&.product&.allow_gift_transfer?
end
|
#allows_transfer? ⇒ Boolean
Ticket Transfer validations
377
378
379
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 377
def allows_transfer?
line_item&.product&.allow_transfer?
end
|
#assign_seat_number_with_bib ⇒ Object
178
179
180
181
182
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 178
def assign_seat_number_with_bib
return if seat_number.present?
assign_seat_number_with_bib!
end
|
#assign_seat_number_with_bib! ⇒ Object
184
185
186
187
188
189
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 184
def assign_seat_number_with_bib!
index = bib_number - 1
positions = line_item.variant.seat_number_positions || []
self.seat_number = (positions[index] if index >= 0 && index < positions.size)
end
|
#assign_seat_number_with_block ⇒ Object
174
175
176
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 174
def assign_seat_number_with_block
self.seat_number = block.present? ? block.label : nil
end
|
#bib_display_prefix? ⇒ Boolean
252
253
254
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 252
def bib_display_prefix?
line_item.variant.bib_display_prefix?
end
|
#bib_required? ⇒ Boolean
248
249
250
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 248
def bib_required?
line_item.variant.bib_required?
end
|
#can_hold_block? ⇒ Boolean
Only allow holding a block if it represents a seat.
Other block types, like standing, don’t need a hold.
Use the variant's inventory item to track availability instead.
95
96
97
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 95
def can_hold_block?
block.present? && block.seatable?
end
|
#can_reserve_block? ⇒ Boolean
Only allow holding a block if it represents a seat.
Other block types, like standing, don’t need a hold.
Use the variant's inventory item to track availability instead.
102
103
104
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 102
def can_reserve_block?
block.present? && block.seatable?
end
|
#cancel_reserved_block! ⇒ Object
362
363
364
365
366
367
368
369
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 362
def cancel_reserved_block!
reserved_block.update!(
status: :canceled,
expired_at: nil,
updated_by: nil,
guest_id: nil
)
end
|
#current_age ⇒ Object
242
243
244
245
246
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 242
def current_age
return nil if dob.nil?
((Time.zone.now - dob.to_time) / 1.year.seconds).floor
end
|
#display_name_with_bib ⇒ Object
195
196
197
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 195
def display_name_with_bib
[full_name, formatted_bib_number, seat_number].compact.join(' | ')
end
|
#eligible_check_in_session_ids ⇒ Object
294
295
296
297
298
299
300
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 294
def eligible_check_in_session_ids
self.public_metadata = JSON.parse(public_metadata) if public_metadata.is_a?(String)
Array(public_metadata['eligible_check_in_session_ids']).map(&:to_i)
end
|
#eligible_check_in_session_ids=(ids) ⇒ Object
302
303
304
305
306
307
308
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 302
def eligible_check_in_session_ids=(ids)
self.public_metadata = {} if public_metadata.nil?
self.public_metadata = JSON.parse(public_metadata) if public_metadata.is_a?(String)
public_metadata['eligible_check_in_session_ids'] = ids
end
|
#eligible_check_in_sessions ⇒ Object
#eligible_for_session?(check_in_session) ⇒ Boolean
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 321
def eligible_for_session?(check_in_session)
rules = check_in_session.check_in_rules
return true if rules.empty?
rules.any? do |rule|
case rule.ruleable_type
when 'Spree::Product'
line_item.product_id == rule.ruleable_id
when 'Spree::Variant'
line_item.variant_id == rule.ruleable_id
when 'Spree::OptionValue'
line_item.variant.option_value_ids.include?(rule.ruleable_id)
else
false
end
end
end
|
#event_started? ⇒ Boolean
385
386
387
388
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 385
def event_started?
event_from_date = event&.from_date
event_from_date.present? && event_from_date <= Time.current
end
|
#external_qr_data ⇒ Object
QR data for check-in. If external_wins? is true, use their QR data (they have their own check-in system).
Otherwise, use our system's QR data. Only applicable to models with QR support (e.g., line_item, guest).
235
236
237
238
239
240
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 235
def external_qr_data
return nil if line_item.nil? || !line_item.integration?
mapping = external_wins_integration_mappings.first
mapping.external_qr_data if mapping.present?
end
|
bib_number: 345, bib_prefix: 5KM, bib_zerofill: 5 => return 5KM00345
bib_number: 345, bib_prefix: 5KM, bib_zerofill: 2 => return 5KM345
258
259
260
261
262
263
264
265
266
267
268
269
270
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 258
def formatted_bib_number
return nil if line_item.blank? || line_item.variant.blank?
return nil if bib_prefix.blank?
return nil if bib_number.blank?
filled_bib_number = bib_number.to_s.rjust(line_item.variant.bib_zerofill.to_i, '0')
if bib_display_prefix?
"#{bib_prefix}#{filled_bib_number}"
else
filled_bib_number
end
end
|
#full_name ⇒ Object
191
192
193
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 191
def full_name
[first_name, last_name].compact_blank.join(' ')
end
|
#generate_png_qr(size = 120) ⇒ Object
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 211
def generate_png_qr(size = 120)
qrcode = RQRCode::QRCode.new(qr_data)
qrcode.as_png(
bit_depth: 1,
border_modules: 1,
color_mode: ChunkyPNG::COLOR_GRAYSCALE,
color: 'black',
file: nil,
fill: 'white',
module_px_size: 4,
resize_exactly_to: false,
resize_gte_to: false,
size: size
)
end
|
#generate_svg_qr ⇒ Object
199
200
201
202
203
204
205
206
207
208
209
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 199
def generate_svg_qr
qrcode = RQRCode::QRCode.new(qr_data)
qrcode.as_svg(
color: '000',
shape_rendering: 'crispEdges',
module_size: 5,
standalone: true,
use_path: true,
viewbox: '0 0 20 10'
)
end
|
#preload_eligible_check_in_session_ids ⇒ Object
310
311
312
313
314
315
316
317
318
319
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 310
def preload_eligible_check_in_session_ids
event = self.event || line_item&.event
return if event.blank?
self.eligible_check_in_session_ids = event.active_check_in_sessions
.select { |session| eligible_for_session?(session) }
.map(&:id)
.uniq
end
|
#preload_order_block_ids ⇒ Object
286
287
288
289
290
291
292
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 286
def preload_order_block_ids
return if line_item.blank?
return if line_item.order.blank?
block_ids = line_item.order.blocks.pluck(:id)
line_item.order.update(preload_block_ids: block_ids)
end
|
#qr_data ⇒ Object
227
228
229
230
231
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 227
def qr_data
return external_qr_data if external_qr_data.present?
token
end
|
#reject_guest_dynamic_field?(attributes) ⇒ Boolean
371
372
373
374
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 371
def reject_guest_dynamic_field?(attributes)
attributes[:dynamic_field_id].blank? || ActiveModel::Type::Boolean.new.cast(attributes[:_destroy])
end
|
#require_kyc_field? ⇒ Boolean
rubocop:disable Metrics/CyclomaticComplexity,Metrics/MethodLength
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 131
def require_kyc_field? kyc_fields.any? do |field|
case field
when :guest_name
first_name.blank? || last_name.blank?
when :guest_gender
gender.blank?
when :guest_dob
dob.blank?
when :guest_age
age.blank?
when :guest_occupation
occupation.blank? && other_occupation.blank?
when :guest_nationality
nationality.blank?
when :guest_emergency_contact
emergency_contact.blank?
when :guest_organization
other_organization.blank?
when :guest_expectation
expectation.blank?
when :guest_social_contact
social_contact_platform.blank? || social_contact.blank?
when :guest_id_card
id_card.blank?
when :guest_address
address.blank?
when :guest_phone_number
phone_number.blank?
when :guest_country_code
country_code.blank?
when :guest_contact
contact.blank?
else
false
end
end
end
|
#set_event_id ⇒ Object
170
171
172
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 170
def set_event_id
self.event_id ||= line_item&.event_id
end
|
#should_validate_block? ⇒ Boolean
validate only if block_id is present AND (new record OR block_id is changing)
goal: don't bother re-validating when block_id stays the same
274
275
276
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 274
def should_validate_block?
block_id.present? && (new_record? || will_save_change_to_block_id?)
end
|
#validate_block ⇒ Object
278
279
280
281
282
283
284
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 278
def validate_block
return if block_id.blank?
return if line_item.blank? || line_item.variant.blank?
return if line_item.variant.blocks.exists?(id: block_id)
errors.add(:block, "does not exist in variant #{line_item.variant_id}")
end
|