Class: SpreeCmCommissioner::Guest
Overview
rubocop:disable Metrics/ClassLength
Constant Summary
Constants included
from KycBitwise
KycBitwise::BIT_FIELDS, KycBitwise::ORDERED_BIT_FIELDS
Class Method Summary
collapse
Instance Method Summary
collapse
Methods included from KycBitwise
#available_social_contact_platforms, #kyc?, #kyc_fields, #kyc_value_enabled?, #unordered_kyc_fields
Class Method Details
.csv_importable_columns ⇒ Object
82
83
84
85
86
87
88
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 82
def self.csv_importable_columns
%i[
first_name last_name phone_number age dob gender address other_occupation
entry_type nationality_id other_organization expectation emergency_contact bib_number
preferred_telegram_user_id seat_number country_code contact
]
end
|
.variants_for_rules(rules) ⇒ Object
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 333
def self.variants_for_rules(rules)
variant_ids = rules.flat_map do |rule|
case rule.ruleable_type
when 'Spree::Product', 'Spree::OptionValue'
rule.ruleable&.variants&.pluck(:id)
when 'Spree::Variant'
[rule.ruleable_id]
else
[]
end
end.compact.flatten.uniq
return [] if variant_ids.empty?
Spree::Variant.where(id: variant_ids).includes(:product, :option_values)
end
|
Instance Method Details
#all_required_dynamic_fields_completed?(stage) ⇒ Boolean
365
366
367
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 365
def all_required_dynamic_fields_completed?(stage)
missing_dynamic_fields_for_stage(stage).blank?
end
|
#allowed_checkout? ⇒ Boolean
no validation for each field as we allow user to save data to model partially.
105
106
107
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 105
def allowed_checkout?
kyc_fields.all? { |field| allowed_checkout_for?(field) }
end
|
#allowed_checkout_for?(field) ⇒ Boolean
rubocop:disable Metrics/AbcSize, Metrics/PerceivedComplexity, Metrics/CyclomaticComplexity
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 109
def allowed_checkout_for?(field) return first_name.present? && last_name.present? if field == :guest_name
return gender.present? if field == :guest_gender
return dob.present? if field == :guest_dob
return occupation.present? || other_occupation.present? if field == :guest_occupation
return nationality.present? if field == :guest_nationality
return age.present? if field == :guest_age
return emergency_contact.present? if field == :guest_emergency_contact
return other_organization.present? if field == :guest_organization
return expectation.present? if field == :guest_expectation
return social_contact_platform.present? && social_contact.present? if field == :guest_social_contact
return upload_later? || (id_card.present? && id_card.allowed_checkout?) if field == :guest_id_card
return address.present? if field == :guest_address
return phone_number.present? if field == :guest_phone_number
return country_code.present? if field == :guest_country_code
return contact.present? if field == :guest_contact
false
end
|
#assign_seat_number_with_bib ⇒ Object
176
177
178
179
180
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 176
def assign_seat_number_with_bib
return if seat_number.present?
assign_seat_number_with_bib!
end
|
#assign_seat_number_with_bib! ⇒ Object
182
183
184
185
186
187
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 182
def assign_seat_number_with_bib!
index = bib_number - 1
positions = line_item.variant.seat_number_positions || []
self.seat_number = (positions[index] if index >= 0 && index < positions.size)
end
|
#assign_seat_number_with_block ⇒ Object
172
173
174
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 172
def assign_seat_number_with_block
self.seat_number = block.present? ? block.label : nil
end
|
#bib_display_prefix? ⇒ Boolean
246
247
248
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 246
def bib_display_prefix?
line_item.variant.bib_display_prefix?
end
|
#bib_required? ⇒ Boolean
242
243
244
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 242
def bib_required?
line_item.variant.bib_required?
end
|
#can_hold_block? ⇒ Boolean
Only allow holding a block if it represents a seat. Other block types, like standing, don’t need a hold. Use the variant’s inventory item to track availability instead.
93
94
95
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 93
def can_hold_block?
block.present? && block.seatable?
end
|
#can_reserve_block? ⇒ Boolean
Only allow holding a block if it represents a seat. Other block types, like standing, don’t need a hold. Use the variant’s inventory item to track availability instead.
100
101
102
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 100
def can_reserve_block?
block.present? && block.seatable?
end
|
#cancel_reserved_block! ⇒ Object
356
357
358
359
360
361
362
363
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 356
def cancel_reserved_block!
reserved_block.update!(
status: :canceled,
expired_at: nil,
updated_by: nil,
guest_id: nil
)
end
|
#check_in_completed? ⇒ Boolean
435
436
437
438
439
440
441
442
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 435
def check_in_completed?
return false unless line_item&.order&.completed?
return true unless line_item&.product&.dynamic_fields&.during_check_in&.any?
required_fields = line_item.product.dynamic_fields.during_check_in.pluck(:id)
filled_fields = guest_dynamic_fields.where(dynamic_field_id: required_fields).pluck(:dynamic_field_id)
(required_fields - filled_fields).empty?
end
|
#completed_phases ⇒ Object
409
410
411
412
413
414
415
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 409
def completed_phases
phases = []
phases << 'pre_registration' if pre_registration_completed?
phases << 'post_registration' if post_registration_completed?
phases << 'during_check_in' if check_in_completed?
phases
end
|
#current_age ⇒ Object
236
237
238
239
240
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 236
def current_age
return nil if dob.nil?
((Time.zone.now - dob.to_time) / 1.year.seconds).floor
end
|
#during_check_in_fields? ⇒ Boolean
452
453
454
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 452
def during_check_in_fields?
line_item&.product&.dynamic_fields&.during_check_in&.any?
end
|
#eligible_check_in_session_ids ⇒ Object
288
289
290
291
292
293
294
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 288
def eligible_check_in_session_ids
self.public_metadata = JSON.parse(public_metadata) if public_metadata.is_a?(String)
Array(public_metadata['eligible_check_in_session_ids']).map(&:to_i)
end
|
#eligible_check_in_session_ids=(ids) ⇒ Object
296
297
298
299
300
301
302
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 296
def eligible_check_in_session_ids=(ids)
self.public_metadata = {} if public_metadata.nil?
self.public_metadata = JSON.parse(public_metadata) if public_metadata.is_a?(String)
public_metadata['eligible_check_in_session_ids'] = ids
end
|
#eligible_check_in_sessions ⇒ Object
#eligible_for_session?(check_in_session) ⇒ Boolean
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 315
def eligible_for_session?(check_in_session)
rules = check_in_session.check_in_rules
return true if rules.empty?
rules.any? do |rule|
case rule.ruleable_type
when 'Spree::Product'
line_item.product_id == rule.ruleable_id
when 'Spree::Variant'
line_item.variant_id == rule.ruleable_id
when 'Spree::OptionValue'
line_item.variant.option_value_ids.include?(rule.ruleable_id)
else
false
end
end
end
|
#external_qr_data ⇒ Object
QR data for check-in. If external_wins? is true, use their QR data (they have their own check-in system). Otherwise, use our system’s QR data. Only applicable to models with QR support (e.g., line_item, guest).
229
230
231
232
233
234
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 229
def external_qr_data
return nil if line_item.nil? || !line_item.integration?
mapping = external_wins_integration_mappings.first
mapping.external_qr_data if mapping.present?
end
|
bib_number: 345, bib_prefix: 5KM, bib_zerofill: 5 => return 5KM00345 bib_number: 345, bib_prefix: 5KM, bib_zerofill: 2 => return 5KM345
252
253
254
255
256
257
258
259
260
261
262
263
264
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 252
def formatted_bib_number
return nil if line_item.blank? || line_item.variant.blank?
return nil if bib_prefix.blank?
return nil if bib_number.blank?
filled_bib_number = bib_number.to_s.rjust(line_item.variant.bib_zerofill.to_i, '0')
if bib_display_prefix?
"#{bib_prefix}#{filled_bib_number}"
else
filled_bib_number
end
end
|
#full_name ⇒ Object
189
190
191
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 189
def full_name
[first_name, last_name].compact_blank.join(' ')
end
|
#generate_png_qr(size = 120) ⇒ Object
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 205
def generate_png_qr(size = 120)
qrcode = RQRCode::QRCode.new(qr_data)
qrcode.as_png(
bit_depth: 1,
border_modules: 1,
color_mode: ChunkyPNG::COLOR_GRAYSCALE,
color: 'black',
file: nil,
fill: 'white',
module_px_size: 4,
resize_exactly_to: false,
resize_gte_to: false,
size: size
)
end
|
#generate_svg_qr ⇒ Object
193
194
195
196
197
198
199
200
201
202
203
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 193
def generate_svg_qr
qrcode = RQRCode::QRCode.new(qr_data)
qrcode.as_svg(
color: '000',
shape_rendering: 'crispEdges',
module_size: 5,
standalone: true,
use_path: true,
viewbox: '0 0 20 10'
)
end
|
#guest_incomplete?(guest) ⇒ Boolean
502
503
504
505
506
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 502
def guest_incomplete?(guest)
(guest.pre_registration_fields? && !guest.pre_registration_completed?) ||
(guest.post_registration_fields? && !guest.post_registration_completed?) ||
(guest.during_check_in_fields? && !guest.check_in_completed?)
end
|
#missing_dynamic_fields_for_stage(stage) ⇒ Object
460
461
462
463
464
465
466
467
468
469
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 460
def missing_dynamic_fields_for_stage(stage)
return [] if line_item.blank? || line_item.product.blank?
@product_dynamic_fields ||= line_item.product.dynamic_fields
required_fields = @product_dynamic_fields.where(data_fill_stage: stage)
filled_ids = guest_dynamic_fields&.pluck(:dynamic_field_id) || []
required_fields.reject { |field| filled_ids.include?(field.id) }
end
|
#order_has_incomplete_guests?(order) ⇒ Boolean
494
495
496
497
498
499
500
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 494
def order_has_incomplete_guests?(order)
order.line_items.any? do |line_item|
line_item.guests.any? do |guest|
guest_incomplete?(guest)
end
end
end
|
#post_registration_completed? ⇒ Boolean
426
427
428
429
430
431
432
433
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 426
def post_registration_completed?
return false unless line_item&.order&.completed?
return true unless line_item&.product&.dynamic_fields&.post_registration&.any?
required_fields = line_item.product.dynamic_fields.post_registration.pluck(:id)
filled_fields = guest_dynamic_fields.where(dynamic_field_id: required_fields).pluck(:dynamic_field_id)
(required_fields - filled_fields).empty?
end
|
#post_registration_fields? ⇒ Boolean
448
449
450
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 448
def post_registration_fields?
line_item&.product&.dynamic_fields&.post_registration&.any?
end
|
#pre_registration_completed? ⇒ Boolean
417
418
419
420
421
422
423
424
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 417
def pre_registration_completed?
return false unless line_item&.order&.completed?
return true unless line_item&.product&.dynamic_fields&.pre_registration&.any?
required_fields = line_item.product.dynamic_fields.pre_registration.pluck(:id)
filled_fields = guest_dynamic_fields.where(dynamic_field_id: required_fields).pluck(:dynamic_field_id)
(required_fields - filled_fields).empty?
end
|
#pre_registration_fields? ⇒ Boolean
444
445
446
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 444
def pre_registration_fields?
line_item&.product&.dynamic_fields&.pre_registration&.any?
end
|
#preload_eligible_check_in_session_ids ⇒ Object
304
305
306
307
308
309
310
311
312
313
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 304
def preload_eligible_check_in_session_ids
event = self.event || line_item&.event
return if event.blank?
self.eligible_check_in_session_ids = event.active_check_in_sessions
.select { |session| eligible_for_session?(session) }
.map(&:id)
.uniq
end
|
#preload_order_block_ids ⇒ Object
280
281
282
283
284
285
286
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 280
def preload_order_block_ids
return if line_item.blank?
return if line_item.order.blank?
block_ids = line_item.order.blocks.pluck(:id)
line_item.order.update(preload_block_ids: block_ids)
end
|
#product_dynamic_fields ⇒ Object
456
457
458
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 456
def product_dynamic_fields
@product_dynamic_fields ||= line_item.product.dynamic_fields
end
|
#qr_data ⇒ Object
221
222
223
224
225
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 221
def qr_data
return external_qr_data if external_qr_data.present?
token
end
|
#reject_guest_dynamic_field?(attributes) ⇒ Boolean
471
472
473
474
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 471
def reject_guest_dynamic_field?(attributes)
attributes[:dynamic_field_id].blank? || ActiveModel::Type::Boolean.new.cast(attributes[:_destroy])
end
|
#require_kyc_field? ⇒ Boolean
rubocop:disable Metrics/CyclomaticComplexity,Metrics/MethodLength
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 129
def require_kyc_field? kyc_fields.any? do |field|
case field
when :guest_name
first_name.blank? || last_name.blank?
when :guest_gender
gender.blank?
when :guest_dob
dob.blank?
when :guest_age
age.blank?
when :guest_occupation
occupation.blank? && other_occupation.blank?
when :guest_nationality
nationality.blank?
when :guest_emergency_contact
emergency_contact.blank?
when :guest_organization
other_organization.blank?
when :guest_expectation
expectation.blank?
when :guest_social_contact
social_contact_platform.blank? || social_contact.blank?
when :guest_id_card
id_card.blank?
when :guest_address
address.blank?
when :guest_phone_number
phone_number.blank?
when :guest_country_code
country_code.blank?
when :guest_contact
contact.blank?
else
false
end
end
end
|
#save_and_move_to_next_stage(_transition = nil) ⇒ Object
397
398
399
400
401
402
403
404
405
406
407
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 397
def save_and_move_to_next_stage(_transition = nil)
case data_fill_stage_phase
when 'pre_registration'
complete_pre_registration! if pre_registration_completed?
when 'post_registration'
complete_post_registration! if post_registration_completed?
when 'during_check_in'
complete_check_in! if check_in_completed?
end
end
|
#set_event_id ⇒ Object
168
169
170
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 168
def set_event_id
self.event_id ||= line_item&.event_id
end
|
#should_update_incomplete_guest_info? ⇒ Boolean
508
509
510
511
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 508
def should_update_incomplete_guest_info?
saved_change_to_data_fill_stage_phase? ||
(guest_dynamic_fields.any? && (guest_dynamic_fields.any?(&:saved_changes?) || guest_dynamic_fields.any?(&:destroyed?)))
end
|
#should_validate_block? ⇒ Boolean
validate only if block_id is present AND (new record OR block_id is changing) goal: don’t bother re-validating when block_id stays the same
268
269
270
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 268
def should_validate_block?
block_id.present? && (new_record? || will_save_change_to_block_id?)
end
|
#update_user_incomplete_guest_info_status ⇒ Object
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 476
def update_user_incomplete_guest_info_status
return unless user
return unless line_item&.order&.completed?
user.reload
has_incomplete = user.orders.complete.any? do |order|
order_has_incomplete_guests?(order)
end
current_status = user.public_metadata['has_incomplete_guest_info'] || false
return unless current_status != has_incomplete
user.public_metadata['has_incomplete_guest_info'] = has_incomplete
user.save!
end
|
#validate_block ⇒ Object
272
273
274
275
276
277
278
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 272
def validate_block
return if block_id.blank?
return if line_item.blank? || line_item.variant.blank?
return if line_item.variant.blocks.exists?(id: block_id)
errors.add(:block, "does not exist in variant #{line_item.variant_id}")
end
|