Class: SpreeCmCommissioner::Guest
Overview
rubocop:disable Metrics/ClassLength
Constant Summary
Constants included
from KycBitwise
KycBitwise::BIT_FIELDS, KycBitwise::ORDERED_BIT_FIELDS
Class Method Summary
collapse
Instance Method Summary
collapse
Methods included from KycBitwise
#available_social_contact_platforms, #kyc?, #kyc_fields, #kyc_value_enabled?, #unordered_kyc_fields
Class Method Details
.csv_importable_columns ⇒ Object
77
78
79
80
81
82
83
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 77
def self.csv_importable_columns
%i[
first_name last_name phone_number age dob gender address other_occupation
entry_type nationality_id other_organization expectation emergency_contact bib_number
preferred_telegram_user_id seat_number country_code contact
]
end
|
Instance Method Details
#all_required_dynamic_fields_completed?(stage) ⇒ Boolean
312
313
314
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 312
def all_required_dynamic_fields_completed?(stage)
missing_dynamic_fields_for_stage(stage).blank?
end
|
#allowed_checkout? ⇒ Boolean
no validation for each field as we allow user to save data to model partially.
100
101
102
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 100
def allowed_checkout?
kyc_fields.all? { |field| allowed_checkout_for?(field) }
end
|
#allowed_checkout_for?(field) ⇒ Boolean
rubocop:disable Metrics/AbcSize, Metrics/PerceivedComplexity, Metrics/CyclomaticComplexity
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 104
def allowed_checkout_for?(field) return first_name.present? && last_name.present? if field == :guest_name
return gender.present? if field == :guest_gender
return dob.present? if field == :guest_dob
return occupation.present? || other_occupation.present? if field == :guest_occupation
return nationality.present? if field == :guest_nationality
return age.present? if field == :guest_age
return emergency_contact.present? if field == :guest_emergency_contact
return other_organization.present? if field == :guest_organization
return expectation.present? if field == :guest_expectation
return social_contact_platform.present? && social_contact.present? if field == :guest_social_contact
return upload_later? || (id_card.present? && id_card.allowed_checkout?) if field == :guest_id_card
return address.present? if field == :guest_address
return phone_number.present? if field == :guest_phone_number
return country_code.present? if field == :guest_country_code
return contact.present? if field == :guest_contact
false
end
|
#assign_seat_number_with_bib ⇒ Object
171
172
173
174
175
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 171
def assign_seat_number_with_bib
return if seat_number.present?
assign_seat_number_with_bib!
end
|
#assign_seat_number_with_bib! ⇒ Object
177
178
179
180
181
182
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 177
def assign_seat_number_with_bib!
index = bib_number - 1
positions = line_item.variant.seat_number_positions || []
self.seat_number = (positions[index] if index >= 0 && index < positions.size)
end
|
#assign_seat_number_with_block ⇒ Object
167
168
169
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 167
def assign_seat_number_with_block
self.seat_number = block.present? ? block.label : nil
end
|
#bib_display_prefix? ⇒ Boolean
241
242
243
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 241
def bib_display_prefix?
line_item.variant.bib_display_prefix?
end
|
#bib_required? ⇒ Boolean
237
238
239
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 237
def bib_required?
line_item.variant.bib_prefix.present?
end
|
#can_check_in?(session) ⇒ Boolean
424
425
426
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 424
def can_check_in?(session)
eligible_check_in_sessions.include?(session)
end
|
#can_hold_block? ⇒ Boolean
Only allow holding a block if it represents a seat. Other block types, like standing, don’t need a hold. Use the variant’s inventory item to track availability instead.
88
89
90
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 88
def can_hold_block?
block.present? && block.seatable?
end
|
#can_reserve_block? ⇒ Boolean
Only allow holding a block if it represents a seat. Other block types, like standing, don’t need a hold. Use the variant’s inventory item to track availability instead.
95
96
97
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 95
def can_reserve_block?
block.present? && block.seatable?
end
|
#cancel_reserved_block! ⇒ Object
303
304
305
306
307
308
309
310
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 303
def cancel_reserved_block!
reserved_block.update!(
status: :canceled,
expired_at: nil,
updated_by: nil,
guest_id: nil
)
end
|
#check_in_completed? ⇒ Boolean
382
383
384
385
386
387
388
389
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 382
def check_in_completed?
return false unless line_item&.order&.completed?
return true unless line_item&.product&.dynamic_fields&.during_check_in&.any?
required_fields = line_item.product.dynamic_fields.during_check_in.pluck(:id)
filled_fields = guest_dynamic_fields.where(dynamic_field_id: required_fields).pluck(:dynamic_field_id)
(required_fields - filled_fields).empty?
end
|
#cm_check_in_rules ⇒ Object
403
404
405
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 403
def cm_check_in_rules
SpreeCmCommissioner::CheckInRule.where(ruleable_id: line_item.product_id)
end
|
#completed_phases ⇒ Object
356
357
358
359
360
361
362
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 356
def completed_phases
phases = []
phases << 'pre_registration' if pre_registration_completed?
phases << 'post_registration' if post_registration_completed?
phases << 'during_check_in' if check_in_completed?
phases
end
|
#current_age ⇒ Object
231
232
233
234
235
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 231
def current_age
return nil if dob.nil?
((Time.zone.now - dob.to_time) / 1.year.seconds).floor
end
|
#during_check_in_fields? ⇒ Boolean
399
400
401
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 399
def during_check_in_fields?
line_item&.product&.dynamic_fields&.during_check_in&.any?
end
|
#eligible_check_in_sessions ⇒ Object
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 407
def eligible_check_in_sessions
check_in_session_ids = []
cm_check_in_rules.includes(:check_in_session).find_each do |rule|
case rule.ruleable_type
when 'Spree::Product'
check_in_session_ids << rule.check_in_session_id if line_item.product_id == rule.ruleable_id
when 'Spree::Variant'
check_in_session_ids << rule.check_in_session_id if line_item.variant_id == rule.ruleable_id
when 'Spree::OptionValue'
check_in_session_ids << rule.check_in_session_id if line_item.variant.option_value_ids.include?(rule.ruleable_id)
end
end
SpreeCmCommissioner::CheckInSession.where(id: check_in_session_ids.uniq)
end
|
#external_qr_data ⇒ Object
QR data for check-in. If external_wins? is true, use their QR data (they have their own check-in system). Otherwise, use our system’s QR data. Only applicable to models with QR support (e.g., line_item, guest).
224
225
226
227
228
229
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 224
def external_qr_data
return nil if line_item.nil? || !line_item.integration?
mapping = external_wins_integration_mappings.first
mapping.external_qr_data if mapping.present?
end
|
bib_number: 345, bib_prefix: 5KM, bib_zerofill: 5 => return 5KM00345 bib_number: 345, bib_prefix: 5KM, bib_zerofill: 2 => return 5KM345
267
268
269
270
271
272
273
274
275
276
277
278
279
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 267
def formatted_bib_number
return nil if line_item.blank? || line_item.variant.blank?
return nil if bib_prefix.blank?
return nil if bib_number.blank?
filled_bib_number = bib_number.to_s.rjust(line_item.variant.bib_zerofill.to_i, '0')
if bib_display_prefix?
"#{bib_prefix}#{filled_bib_number}"
else
filled_bib_number
end
end
|
#full_name ⇒ Object
184
185
186
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 184
def full_name
[first_name, last_name].compact_blank.join(' ')
end
|
#generate_bib ⇒ Object
245
246
247
248
249
250
251
252
253
254
255
256
257
258
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 245
def generate_bib
return if bib_prefix.present?
return unless bib_required?
return if event_id.blank?
self.bib_prefix = line_item.variant.bib_prefix
last_bib_number = event.guests
.where(bib_prefix: bib_prefix)
.maximum(:bib_number) || 0
self.bib_number = last_bib_number + 1
self.bib_index = "#{event_id}-#{bib_prefix}-#{bib_number}"
end
|
#generate_bib! ⇒ Object
260
261
262
263
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 260
def generate_bib!
generate_bib
save!
end
|
#generate_png_qr(size = 120) ⇒ Object
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 200
def generate_png_qr(size = 120)
qrcode = RQRCode::QRCode.new(qr_data)
qrcode.as_png(
bit_depth: 1,
border_modules: 1,
color_mode: ChunkyPNG::COLOR_GRAYSCALE,
color: 'black',
file: nil,
fill: 'white',
module_px_size: 4,
resize_exactly_to: false,
resize_gte_to: false,
size: size
)
end
|
#generate_svg_qr ⇒ Object
188
189
190
191
192
193
194
195
196
197
198
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 188
def generate_svg_qr
qrcode = RQRCode::QRCode.new(qr_data)
qrcode.as_svg(
color: '000',
shape_rendering: 'crispEdges',
module_size: 5,
standalone: true,
use_path: true,
viewbox: '0 0 20 10'
)
end
|
#guest_incomplete?(guest) ⇒ Boolean
474
475
476
477
478
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 474
def guest_incomplete?(guest)
(guest.pre_registration_fields? && !guest.pre_registration_completed?) ||
(guest.post_registration_fields? && !guest.post_registration_completed?) ||
(guest.during_check_in_fields? && !guest.check_in_completed?)
end
|
#missing_dynamic_fields_for_stage(stage) ⇒ Object
432
433
434
435
436
437
438
439
440
441
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 432
def missing_dynamic_fields_for_stage(stage)
return [] if line_item.blank? || line_item.product.blank?
@product_dynamic_fields ||= line_item.product.dynamic_fields
required_fields = @product_dynamic_fields.where(data_fill_stage: stage)
filled_ids = guest_dynamic_fields&.pluck(:dynamic_field_id) || []
required_fields.reject { |field| filled_ids.include?(field.id) }
end
|
#order_has_incomplete_guests?(order) ⇒ Boolean
466
467
468
469
470
471
472
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 466
def order_has_incomplete_guests?(order)
order.line_items.any? do |line_item|
line_item.guests.any? do |guest|
guest_incomplete?(guest)
end
end
end
|
#post_registration_completed? ⇒ Boolean
373
374
375
376
377
378
379
380
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 373
def post_registration_completed?
return false unless line_item&.order&.completed?
return true unless line_item&.product&.dynamic_fields&.post_registration&.any?
required_fields = line_item.product.dynamic_fields.post_registration.pluck(:id)
filled_fields = guest_dynamic_fields.where(dynamic_field_id: required_fields).pluck(:dynamic_field_id)
(required_fields - filled_fields).empty?
end
|
#post_registration_fields? ⇒ Boolean
395
396
397
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 395
def post_registration_fields?
line_item&.product&.dynamic_fields&.post_registration&.any?
end
|
#pre_registration_completed? ⇒ Boolean
364
365
366
367
368
369
370
371
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 364
def pre_registration_completed?
return false unless line_item&.order&.completed?
return true unless line_item&.product&.dynamic_fields&.pre_registration&.any?
required_fields = line_item.product.dynamic_fields.pre_registration.pluck(:id)
filled_fields = guest_dynamic_fields.where(dynamic_field_id: required_fields).pluck(:dynamic_field_id)
(required_fields - filled_fields).empty?
end
|
#pre_registration_fields? ⇒ Boolean
391
392
393
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 391
def pre_registration_fields?
line_item&.product&.dynamic_fields&.pre_registration&.any?
end
|
#preload_order_block_ids ⇒ Object
295
296
297
298
299
300
301
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 295
def preload_order_block_ids
return if line_item.blank?
return if line_item.order.blank?
block_ids = line_item.order.blocks.pluck(:id)
line_item.order.update(preload_block_ids: block_ids)
end
|
#product_dynamic_fields ⇒ Object
428
429
430
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 428
def product_dynamic_fields
@product_dynamic_fields ||= line_item.product.dynamic_fields
end
|
#qr_data ⇒ Object
216
217
218
219
220
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 216
def qr_data
return external_qr_data if external_qr_data.present?
token
end
|
#reject_guest_dynamic_field?(attributes) ⇒ Boolean
443
444
445
446
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 443
def reject_guest_dynamic_field?(attributes)
attributes[:dynamic_field_id].blank? || ActiveModel::Type::Boolean.new.cast(attributes[:_destroy])
end
|
#require_kyc_field? ⇒ Boolean
rubocop:disable Metrics/CyclomaticComplexity,Metrics/MethodLength
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 124
def require_kyc_field? kyc_fields.any? do |field|
case field
when :guest_name
first_name.blank? || last_name.blank?
when :guest_gender
gender.blank?
when :guest_dob
dob.blank?
when :guest_age
age.blank?
when :guest_occupation
occupation.blank? && other_occupation.blank?
when :guest_nationality
nationality.blank?
when :guest_emergency_contact
emergency_contact.blank?
when :guest_organization
other_organization.blank?
when :guest_expectation
expectation.blank?
when :guest_social_contact
social_contact_platform.blank? || social_contact.blank?
when :guest_id_card
id_card.blank?
when :guest_address
address.blank?
when :guest_phone_number
phone_number.blank?
when :guest_country_code
country_code.blank?
when :guest_contact
contact.blank?
else
false
end
end
end
|
#save_and_move_to_next_stage(_transition = nil) ⇒ Object
344
345
346
347
348
349
350
351
352
353
354
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 344
def save_and_move_to_next_stage(_transition = nil)
case data_fill_stage_phase
when 'pre_registration'
complete_pre_registration! if pre_registration_completed?
when 'post_registration'
complete_post_registration! if post_registration_completed?
when 'during_check_in'
complete_check_in! if check_in_completed?
end
end
|
#set_event_id ⇒ Object
163
164
165
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 163
def set_event_id
self.event_id ||= line_item&.event_id
end
|
#should_update_incomplete_guest_info? ⇒ Boolean
480
481
482
483
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 480
def should_update_incomplete_guest_info?
saved_change_to_data_fill_stage_phase? ||
(guest_dynamic_fields.any? && (guest_dynamic_fields.any?(&:saved_changes?) || guest_dynamic_fields.any?(&:destroyed?)))
end
|
#should_validate_block? ⇒ Boolean
validate only if block_id is present AND (new record OR block_id is changing) goal: don’t bother re-validating when block_id stays the same
283
284
285
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 283
def should_validate_block?
block_id.present? && (new_record? || will_save_change_to_block_id?)
end
|
#update_user_incomplete_guest_info_status ⇒ Object
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 448
def update_user_incomplete_guest_info_status
return unless user
return unless line_item&.order&.completed?
user.reload
has_incomplete = user.orders.complete.any? do |order|
order_has_incomplete_guests?(order)
end
current_status = user.public_metadata['has_incomplete_guest_info'] || false
return unless current_status != has_incomplete
user.public_metadata['has_incomplete_guest_info'] = has_incomplete
user.save!
end
|
#validate_block ⇒ Object
287
288
289
290
291
292
293
|
# File 'app/models/spree_cm_commissioner/guest.rb', line 287
def validate_block
return if block_id.blank?
return if line_item.blank? || line_item.variant.blank?
return if line_item.variant.blocks.exists?(id: block_id)
errors.add(:block, "does not exist in variant #{line_item.variant_id}")
end
|