Class: SpreeCmCommissioner::VotingSession
- Includes:
- StoreMetadata
- Defined in:
- app/models/spree_cm_commissioner/voting_session.rb
Constant Summary collapse
- DEFAULT_SUGGESTION_TOP_N =
1
Class Method Summary collapse
-
.current_or_next_upcoming ⇒ Object
Priority 1: Current session wins over Upcoming session.
Instance Method Summary collapse
- #active? ⇒ Boolean
- #can_vote? ⇒ Boolean
- #effective_fraud_config ⇒ Object
- #effective_suggestion_top_n ⇒ Object
- #effective_voting_config ⇒ Object
- #embedded_live_stream_url ⇒ Object
- #find_or_create_voting_contestant(show_contestant) ⇒ Object
-
#first_in_episode? ⇒ Boolean
True when this session is the first in its episode.
- #max_votes_per_user ⇒ Object
-
#missing_show_contestants ⇒ Object
Show contestants expected in this session but not yet assigned.
-
#next_in_episode ⇒ Object
Returns the next session within the same episode (by position).
- #past? ⇒ Boolean
- #paused? ⇒ Boolean
- #rate_limit_max_votes ⇒ Object
- #rate_limit_window ⇒ Object
- #upcoming? ⇒ Boolean
Class Method Details
.current_or_next_upcoming ⇒ Object
Priority 1: Current session wins over Upcoming session. Priority 2: Follow manual position (Managed by acts_as_list).
55 56 57 58 59 60 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 55 def self.current_or_next_upcoming current.or(upcoming).order( Arel.sql('CASE WHEN opens_at <= CURRENT_TIMESTAMP AND closes_at >= CURRENT_TIMESTAMP THEN 0 ELSE 1 END'), :position ) end |
Instance Method Details
#active? ⇒ Boolean
37 38 39 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 37 def active? enabled? && Time.current.between?(opens_at, closes_at) end |
#can_vote? ⇒ Boolean
119 120 121 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 119 def can_vote? enabled? && Time.zone.now.between?(opens_at, closes_at) end |
#effective_fraud_config ⇒ Object
111 112 113 114 115 116 117 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 111 def effective_fraud_config return {} unless show config = parse_json_config(fraud_config) show_config = show.effective_fraud_config config.reverse_merge(show_config || {}) end |
#effective_suggestion_top_n ⇒ Object
86 87 88 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 86 def effective_suggestion_top_n suggestion_top_n&.to_i&.positive? ? suggestion_top_n.to_i : DEFAULT_SUGGESTION_TOP_N end |
#effective_voting_config ⇒ Object
103 104 105 106 107 108 109 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 103 def effective_voting_config return {} unless show config = parse_json_config(voting_config) show_config = show.effective_voting_config config.reverse_merge(show_config || {}) end |
#embedded_live_stream_url ⇒ Object
155 156 157 158 159 160 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 155 def return nil if live_stream_url.blank? result = SpreeCmCommissioner::UrlEmbed::YoutubeEmbed.call(url: live_stream_url) result.success? ? result.value : nil end |
#find_or_create_voting_contestant(show_contestant) ⇒ Object
97 98 99 100 101 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 97 def find_or_create_voting_contestant(show_contestant) voting_contestants.find_or_create_by!(show_contestant: show_contestant) do |vc| vc.show_id = show.id end end |
#first_in_episode? ⇒ Boolean
True when this session is the first in its episode. e.g. position=1 → true; position=2 → false
131 132 133 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 131 def first_in_episode? position == 1 end |
#max_votes_per_user ⇒ Object
143 144 145 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 143 def max_votes_per_user effective_voting_config['max_votes_per_user'] || 10 end |
#missing_show_contestants ⇒ Object
Show contestants expected in this session but not yet assigned. episode.season.show_contestants → all contestants on the season this episode belongs to. show_contestants → already assigned to this voting session. e.g. season has [Alice, Bob, Carol]; session only has [Alice] → returns [Bob, Carol]
139 140 141 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 139 def missing_show_contestants episode.season.show_contestants.where.not(id: show_contestants.select(:id)).ordered end |
#next_in_episode ⇒ Object
Returns the next session within the same episode (by position). e.g. current session position=1 → returns session at position=2; last session → nil
125 126 127 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 125 def next_in_episode episode.voting_sessions.where('position > ?', position).order(:position).first end |
#past? ⇒ Boolean
45 46 47 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 45 def past? closed? || (closes_at.present? && Time.current > closes_at) end |
#paused? ⇒ Boolean
49 50 51 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 49 def paused? disabled? && Time.current.between?(opens_at, closes_at) end |
#rate_limit_max_votes ⇒ Object
151 152 153 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 151 def rate_limit_max_votes effective_voting_config['rate_limit_max_votes'] || 5 end |
#rate_limit_window ⇒ Object
147 148 149 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 147 def rate_limit_window effective_voting_config['rate_limit_window'] || 60 end |
#upcoming? ⇒ Boolean
41 42 43 |
# File 'app/models/spree_cm_commissioner/voting_session.rb', line 41 def upcoming? enabled? && Time.current < opens_at end |